#
# lxc: linux Container library
#
# (C) Copyright IBM Corp. 2007, 2008
#
# Authors:
# Daniel Lezcano <daniel.lezcano at free.fr>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

%global with_python %{?_with_python: 1} %{?!_with_python: 0}
%global with_lua %{?_with_lua: 1} %{?!_with_lua: 0}

# Set with_systemd on distros that use it, so we can install the service
# file, otherwise the sysvinit script will be installed
%if 0%{?fedora} >= 14 || 0%{?rhel} >= 7 || 0%{?suse_version} >= 1210
%global with_systemd 1
%define init_script systemd
#
# BuildRequires systemd-units on fedora and rhel
%if 0%{?fedora} >= 14 || 0%{?rhel} >= 7
BuildRequires: systemd-units
#
# BuildRequires systemd on openSUSE and SUSE
%endif
%if 0%{?suse_version} >= 1210
BuildRequires: systemd
%endif
%else
%global with_systemd 0
%define init_script sysvinit
%endif

# Must use /var/run for runtime_path on older releases or dnsmasq in the
# lxc-net script will not be able to write its pid in /run (selinux denial)
%if 0%{?fedora} < 15 || 0%{?rhel} < 7
%define _with_runtime_path --with-runtime-path=/var/run
%endif

# RPM needs alpha/beta/rc in Release: not Version: to ensure smooth
# package upgrades from alpha->beta->rc->release. For more info see:
# http://fedoraproject.org/wiki/Packaging%3aNamingGuidelines#NonNumericRelease
%if "x" != "x"
%global beta_rel @LXC_VERSION_BETA@
%global beta_dot .%{beta_rel}
%else
%global norm_rel 2.0.14
%endif

Name: lxc
Version: 1.1.5
Release: %{?beta_rel:0.1.%{beta_rel}}%{?!beta_rel:%{norm_rel}}%{?dist}
URL: http://linuxcontainers.org
Source: http://linuxcontainers.org/downloads/%{name}-%{version}%{?beta_dot}.tar.gz
Summary: Linux Containers userspace tools
Group: Applications/System
License: LGPLv2+
BuildRoot: %{_tmppath}/%{name}-%{version}-build
Requires: libcap openssl rsync dnsmasq bridge-utils
Requires: %{name}-libs = %{version}-%{release}
Requires(post): chkconfig
Requires(pre): /usr/sbin/useradd
Requires(postun): /usr/sbin/userdel
%if 0%{?fedora} < 15 || 0%{?rhel} < 7
Requires: libcgroup
%endif
# Note for Suse.  The "docbook2X" BuildRequires does properly
# match docbook2x on Suse in a case insensitive manner
BuildRequires: automake autoconf libcap libcap-devel libselinux-devel docbook-utils graphviz libxslt pkgconfig

#
# Additional packages for openSUSE and SUSE
#
%if 0%{?suse_version} >= 1210
PreReq:   permissions
BuildRequires:  libapparmor-devel linux-glibc-devel lsb-release docbook-utils

#
# libseccomp-devel only needed on i386/i586/i686 and X86_64
#
%ifarch %ix86 x86_64
BuildRequires:  libseccomp-devel
%endif
%endif

%if %{with_python}
Requires: python3
BuildRequires: python3-devel
%endif

Patch0001: 0001-fix-autodev-on-SELinux-enabled-systems.patch
Patch0002: 0002-disable-autodev-by-default-for-ol6.x-containers.patch
Patch0003: 0003-Introducing-privileged-configuration-file.patch
Patch0004: 0004-lxc-oracle-introducing-privileged-flag-RT-support-an.patch
Patch0005: 0005-Dynamic-RT-management-hook-script.patch
Patch0006: 0006-Mechanism-to-reboot-after-an-abrupt-shutdown-is-issu.patch
Patch0007: 0007-lxc-create-doesn-t-work-properly-on-OL-7.2.patch
Patch0008: 0008-Code-re-arrange.patch
Patch0009: 0009-Link-etc-mtab-to-proc-self-mounts-for-OL5-6.patch
Patch0010: 0010-utils-dialback-setproctitle-failure-message.patch
Patch0011: 0011-Fix-btrfs-bus-error-on-sparc-on-snapshot-delete.patch
Patch0012: 0012-Remove-duplicates-lxc.network.hwaddr.patch
Patch0013: 0013-Timezone-inside-the-container-is-not-the-same-as-the.patch
Patch0014: 0014-Correct-the-template-creation-output-for-the-bridge-.patch
Patch0015: 0015-Improve-on-the-case-where-default-networking-config-.patch
Patch0016: 0016-Unable-to-login-via-console-in-OL7.2.patch
Patch0017: 0017-Remove-oracle-user-in-lxc-templates.patch
Patch0018: 0018-security-ensure-target-netns-is-caller-owned.patch
Patch0019: 0019-For-OL5-don-t-mount-selinuxfs-onto-selinux.patch
Patch0020: 0020-Re-label-etc-passwd-to-passwd_file_t-after-chpasswd-.patch 
Patch0021: 0021-Add-aarch64-to-support-ARM-platform.patch
Patch0022: 0022-fix-lxc-ls-shows-double-output.patch
Patch0023: 0023-fix-aarch64-lxc-cgroup-logs-warn.patch
%description
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package provides the lxc-* tools, which can be used to start a single
daemon in a container, or to boot an entire "containerized" system, and to
manage and debug your containers.

%package	libs
Summary:	Shared library files for %{name}
Group:		System Environment/Libraries
%description	libs
The %{name}-libs package contains libraries for running %{name} applications.

%package	devel
Summary:	Development library for %{name}
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}, pkgconfig
%description	devel
The %{name}-devel package contains header files and library needed for
development of the Linux containers.

%if %{with_lua}
%package	lua
Summary:	Lua bindings for %{name}
Group:		System Environment/Libraries
Requires:	lua-filesystem lua-alt-getopt
BuildRequires:	lua-devel
%description	lua
The %{name}-lua package contains %{name} bindings for lua.
%endif

%prep
%setup -q -n %{name}-%{version}%{?beta_dot}
%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1
%patch0007 -p1
%patch0008 -p1
%patch0009 -p1
%patch0010 -p1
%patch0011 -p1
%patch0012 -p1
%patch0013 -p1
%patch0014 -p1
%patch0015 -p1
%patch0016 -p1
%patch0017 -p1
%patch0018 -p1
%patch0019 -p1
%patch0020 -p1
%patch0021 -p1
%patch0022 -p1
%patch0023 -p1
%build
./autogen.sh
PATH=$PATH:/usr/sbin:/sbin %configure $args \
  --disable-apparmor \
  --enable-configpath-log \
  --with-config-path=/container \
%if %{with_lua}
  --enable-lua \
%else
  --disable-lua \
%endif
%if %{with_python}
  --enable-python \
%else
  --disable-python \
%endif
%if "x%{_unitdir}" != "x"
  --with-systemdsystemunitdir=%{_unitdir} \
%endif
  %{?_with_runtime_path} \
  --disable-rpath \
  --with-init-script=%{init_script}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
find %{buildroot} -type f -name '*.la' -exec rm -f {} ';'

%clean
rm -rf %{buildroot}

%pre
# Ensure that lxc-dnsmasq uid & gid gets correctly allocated
if /usr/bin/getent passwd lxc-dnsmasq >/dev/null 2>&1 ; then : ; else \
 /usr/sbin/useradd -M -r -s /sbin/nologin \
 -c "LXC Networking Service" -d %_localstatedir/%name lxc-dnsmasq 2> /dev/null \
 || exit 1
fi

%post
mkdir -p /container
%if %{with_systemd}
/usr/bin/systemctl enable lxc-net.service
/usr/bin/systemctl enable lxc.service
%else
/sbin/chkconfig --add lxc
/sbin/chkconfig --add lxc-net
/sbin/service lxc-net start
%endif

# This test should trigger a network configure on a new install.
if [ ! -f %{_sysconfdir}/sysconfig/lxc-net ] || ! grep -q 'USE_LXC_BRIDGE=' %{_sysconfdir}/sysconfig/lxc-net
then
	# Grab a random 10net subnet.  Need to add test logic...
	while [ true ]
	do
		SUBNET=10.$(($RANDOM % 256)).$(($RANDOM % 256))
		if ! ip -4 route ls | grep -q "^$SUBNET"
		then
			break
		fi
	done

	cat >  %{_sysconfdir}/sysconfig/lxc-net <<EOF
# Leave USE_LXC_BRIDGE as "true" if you want to use lxcbr0 for your
# containers.  Set to "false" if you'll use virbr0 or another existing
# bridge, or mavlan to your host's NIC.
USE_LXC_BRIDGE="true"

# If you change the LXC_BRIDGE to something other than lxcbr0, then
# you will also need to update your /etc/lxc/default.conf as well as the
# configuration (/var/lib/lxc/<container>/config) for any containers
# already created using the default config to reflect the new bridge
# name.
# If you have the dnsmasq daemon installed, you'll also have to update
# /etc/dnsmasq.d/lxc and restart the system wide dnsmasq daemon.
LXC_BRIDGE="lxcbr0"
LXC_ADDR="$SUBNET.1"
LXC_NETMASK="255.255.255.0"
LXC_NETWORK="$SUBNET.0/24"
LXC_DHCP_RANGE="$SUBNET.2,$SUBNET.254"
LXC_DHCP_MAX="253"
# Uncomment the next line if you'd like to use a conf-file for the lxcbr0
# dnsmasq.  For instance, you can use 'dhcp-host=mail1,10.0.3.100' to have
# container 'mail1' always get ip address 10.0.3.100.
#LXC_DHCP_CONFILE=/etc/lxc/dnsmasq.conf

# Uncomment the next line if you want lxcbr0's dnsmasq to resolve the .lxc
# domain.  You can then add "server=/lxc/10.0.3.1' (or your actual $LXC_ADDR)
# to /etc/dnsmasq.conf, after which 'container1.lxc' will resolve on your
# host.
#LXC_DOMAIN="lxc"
EOF
fi

%preun
if [ "$1" = 0 ]
then
%if %{with_systemd}
  /usr/bin/systemctl disable lxc.service
  /usr/bin/systemctl disable lxc-net.service
%else
  /sbin/chkconfig --del lxc
  /sbin/chkconfig --del lxc-net
%endif
fi

%postun
/usr/sbin/userdel lxc-dnsmasq > /dev/null 2>&1 || :

%post   libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
# openSUSE/SUSE
%if 0%{?suse_version} >= 1210
%dir  %{_sysconfdir}/apparmor.d
%dir  %{_sysconfdir}/apparmor.d/abstractions
%dir  %{_sysconfdir}/apparmor.d/abstractions/%{name}
%config %{_sysconfdir}/apparmor.d/abstractions/%{name}/container-base
%config %{_sysconfdir}/apparmor.d/abstractions/%{name}/start-container
%config %{_sysconfdir}/apparmor.d/%{name}-containers
%dir  %{_sysconfdir}/apparmor.d/%{name}
%config %{_sysconfdir}/apparmor.d/%{name}/%{name}-default
%config %{_sysconfdir}/apparmor.d/%{name}/%{name}-default-with-mounting
%config %{_sysconfdir}/apparmor.d/%{name}/%{name}-default-with-nesting
%config %{_sysconfdir}/apparmor.d/usr.bin.%{name}-start
%endif
%{_mandir}/man1/lxc*
%{_mandir}/man5/lxc*
%{_mandir}/man7/lxc*
%{_datadir}/doc/*
%{_datadir}/lxc/*
%{_sysconfdir}/bash_completion.d
%config(noreplace) %{_sysconfdir}/lxc/*
%config(noreplace) %{_sysconfdir}/sysconfig/*

%if %{with_systemd}
%{_unitdir}/lxc-net.service
%{_unitdir}/lxc.service
%else
%{_sysconfdir}/rc.d/init.d/lxc
%{_sysconfdir}/rc.d/init.d/lxc-net
%endif

%files libs
%defattr(-,root,root)
%{_sbindir}/*
%{_libdir}/*.so.*
%{_libdir}/%{name}
%if %{with_python}
%{_libdir}/python*
%endif
%{_localstatedir}/*
%{_libexecdir}/%{name}
%attr(4111,root,root) %{_libexecdir}/%{name}/lxc-user-nic
%if %{with_systemd}
%attr(555,root,root) %{_libexecdir}/%{name}/lxc-devsetup
%attr(555,root,root) %{_libexecdir}/%{name}/lxc-net
%attr(555,root,root) %{_libexecdir}/%{name}/lxc-containers
%endif

%if %{with_python}
%{_libdir}/python3.3/site-packages/_lxc*
%{_libdir}/python3.3/site-packages/lxc/*
%endif

%if %{with_lua}
%files lua
%defattr(-,root,root)
%{_datadir}/lua
%{_libdir}/lua
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%changelog
* Wed Oct 24 2018 Yinbo Wang <yinbo.wang@oracle.com> - 1.1.5-2.0.14
- [Orabug 27540382] lxc-cgroup logs warning for "unsupported personality 'aarch64'" 

* Wed Sep 27 2018 Yinbo Wang <yinbo.wang@oracle.com> - 1.1.5-2.0.12
- [Orabug 27822290] lxc-ls shows double output

* Mon Apr 16 2018 Yinbo Wang <yinbo.wang@oracle.com> - 1.1.5-2.0.10
- [Orabug 27493594] [aarch64] lxc-create returns error with basic options

* Mon Aug 28 2017 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.9
- [Orabug 26676857] Selinux enable, unable to ssh to OL5 container on OL7 host

* Wed Aug 16 2017 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.8
- For OL5 templates don't mount selinuxfs

* Tue Apr 11 2017 Yinbo Wang <yinbo.wang@oracle.com> - 1.1.5-2.0.7
- [CVE-2017-5985] Ensure target netns is caller-owned

* Wed Jun 08 2016 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.6
- [Orabug 23203992] lxc-create assumes a bridge name and may get it wrong
- [Orabug 23555384] LXC: Unable to login to newly created OL7.2 container
- [Orabug 23557613] lxc: oracle user uid/gid do not match between ol6/ol7

* Thu Apr 14 2016 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.5
- [Orabug 23096664] lxc-create completion message prints wrong bridge
- Removed CRIU dependency for LXC-1.1.5

* Fri Mar 18 2016 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.4
- [Orabug 22960175] /etc/sysconfig/clock missing in containers

* Fri Jan 15 2016 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.3
- setproctile fix
- [Orabug 22534959] btrfs bus error issue on sparc
- [Orabug 22653555] lxc.network.hwaddr field is getting populated twice
  in config file
- start lxc-net in OL6, include CRIU dependency

* Wed Jan 13 2016 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.2
- [Orabug 22451776] lxc-create doesn't work properly on OL 7.2
- lxc-create code cleanup
- [Orabug 22379008] Link /etc/mtab to /proc/self/mounts for OL5&6

* Sun Dec 13 2015 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-2.0.1
- update to upstream 1.1.5
- incorporate patches from 1.1.4

* Sun Nov 15 2015 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.4-2.0.1
- update to upstream 1.1.4
- incorporate patches from 1.1.0-2.0.1
- incorporate various patches from 1.0.7-2.0.4 for various Oracle
  products certification on LXC

* Fri Feb 13 2015 Dwight Engen <dwight.engen@oracle.com> - 1.1.0-2.0.1
- update to upstream 1.1.0
- incorporate patches for correct setting of selinux labels on
  devices nodes created by autodev

* Mon Dec 08 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.7-2.0.1
- update to upstream 1.0.7

* Wed Oct 15 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.6-2.0.1
- update to upstream 1.0.6
- explicitly mention lxc-autostart-helper in %files to match upstream

* Wed Jul 23 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.5-2.0.2
- add libselinux-devel to BuildRequires so that lxc detects SELinux
  in the build environment and builds support for it

* Tue Jul 15 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.5-2.0.1
- update to upstream 1.0.5
- use upstream patch for cgroup:mixed and yum channel name

* Thu Jul 03 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.4-2.0.3
- [Orabug 19152320] Mount cgroup:mixed to prevent systemd from moving
  out of lxc setup cgroup

* Mon Jun 23 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.4-2.0.2
- update channel name to ol7_u0_base for OL7 public-yum

* Fri Jun 13 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.4-2.0.1
- update to upstream 1.0.4

* Thu Apr 10 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.3-2.0.2
- [Orabug 18526838] add back in libcap and libvirt Requires which were
  inadvertantly dropped when updating the .spec file to upstream 1.0

* Wed Apr 09 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.3-2.0.1
- update to upstream 1.0.3
- include patch for installing from any repo (ie. OL7 .iso)
- use db_load from container so we can drop Requires: compat-db43 since
  OL7 doesn't have this package
- adjust lxc.spec for move of libexecdir/lxc-init to sbin/lxc.init

* Mon Mar 31 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.2-2.0.1
- update to upstream 1.0.2
- include patch for yum update within container
- run ./autogen to ensure build env automake version is used since aclocal
  from upstream tarball may be too new

* Fri Mar 14 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.1-2.0.1
- update to upstream 1.0.1

* Thu Feb 20 2014 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-2.0.1
- update to upstream 1.0.0
- update .spec file to align with upstream
- create /container on install if it doesn't already exist
- include Oracle template changes for OL7

* Wed Dec 18 2013 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-0.1.beta1
- update to upstream lxc-1.0.0.alpha2

* Wed Oct 23 2013 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-0.1.alpha2
- update to upstream lxc-1.0.0.alpha2
- fix rpm changelog entries to conform to packaging guidelines
- [Orabug 17190287] restrict writeability in /proc and /sys

* Tue Oct 22 2013 Dwight Engen <dwight.engen@oracle.com> - 1.0.0-0.1.alpha2
- fix some rpmlint warnings/errors
- split lua bits into seperate package

* Fri Jul 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.4
- [Orabug 16316936] fix sem_open(3) by mounting /dev/shm as tmpfs
- [Orabug 17042712] fix sshd template
- [Orabug 17066749] fix hostname in cloned containers

* Thu May  9 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.3
- applied upstream fixes
- oracle build environment for lxc now has newer kernel-headers, which makes
  lxc-attach now work since at build time the the setns syscall introduced
  in kernel 3.7 will be found

* Fri Apr 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.2
- applied upstream patches for other minor issues
- The sparc architecture doesn't have or need a compat-db4* requirement
  in the spec-file
- [Orabug 16656944] lxc-clone fails

* Mon Apr 08 2013 Dwight Engen <dwight.engen@oracle.com> - 0.9.0-2.0.1
- update to upstream 0.9.0
- lxc.spec: remove patches that have been upstreamed
- patch back to building docs with docbook-utils instead of docbook2X

* Tue Mar 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.9
- move .rpmdb on Debian host
- [Orabug 16327664] fix cosmetic error on ol5 cp resolv.conf
- [Orabug 16297950] silence cosmetic "cat /proc/self/attr/current" error

* Thu Feb 14 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.8
- [Orabug 16324116] handle 5.latest correctly in redo_pkgs
- [Orabug 16327382] commenting out of "Remounting rootfs" in rc.sysinit

* Wed Feb 13 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.7
- use libvirt for rpm Requires not libvirt-daemon

* Tue Feb 12 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.6
- [Orabug 16297177] default to same release as host
- [Orabug 16297404] add libvirt-daemon and compat-db43 as rpm Requires
- [Orabug 16297950] set selinux labels on devices created by oracle template
- [Orabug 16302675] don't attempt to remount / (superficial error message)
- [Orabug 16303282] don't attempt to unmount swap in container halt
- [Orabug 16304447] bad copy when using oracle templatefs -t option
- [Orabug 16316699] lxc-ls returning non-container directories

* Fri Feb 08 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.5
- merge all oracle template patches into one, update to latest to handle
  ol4 better and handle some selinux cases
- remove distro config /etc/lxc/lxc.conf patch since it is not needed and
  the name is changing in 0.9.0
- [Orabug 16296667] fix misapplied patch in lxc-shutdown

* Wed Jan 09 2013 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.4
- [Orabug 16010534] prevent insmod, rmmod (git d378aebe)
- [Orabug 16071473] document <Ctrl-a q> to escape lxc-console (git 76848789)
- [Orabug 16090880] lxc-shutdown not working

* Fri Dec 28 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.3
- fix creation of busybox based containers
- [Orabug 15984742] lxc-destroy only allowed in the STOPPED state
- [Orabug 15989848] lxc-wait hangs waiting for state FROZEN,FREEZING, or THAWED

* Fri Dec 14 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.2
- fix use with OVM template rootfs
- add support for creating ol4 container from OVM template
- [Orabug 15984921], [Orabug 15972116] fix race/corruption with multiple
  lxc-start, lxc-execute

* Tue Dec  4 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2.0.1
- Add autoconf, automake to BuildRequires since patch0001 modifies configure.ac,
  and if the build files are not regenerated the Oracle template will not be
  included.
  
* Wed Nov 21 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0-2
- include oracle template
- set container directory to /container

* Mon Sep 10 2012 Dwight Engen <dwight.engen@oracle.com> - 0.8.0
- fix lxc-init moved to libexec
- .pc moved to _libdir
- package template files /usr/share/lxc/templates

* Thu Sep  8 2011 Greg Kurz <gkurz@fr.ibm.com> - 0.7.5.1
- fix installed files for rpmbuild
- introduce lxc-libs package

* Fri Jul 23 2010 Daniel Lezcano <dlezcano@fr.ibm.com> - 0.7.2
- set attribute for installed files
- fix libraries installation

* Tue Mar 24 2009 Daniel Lezcano <daniel.lezcano@free.fr> - 0.6.1
- Removed capability setting, let the user to do that through "lxc-setcap"

* Mon Feb 16 2009 Daniel Lezcano <daniel.lezcano@free.fr> - 0.6.0
- Added more capabilities to the executables

* Sun Jan 25 2009 Daniel Lezcano <daniel.lezcano@free.fr> - 0.6.0
- Reduced spec file

* Sun Aug 3 2008 Daniel Lezcano <dlezcano@fr.ibm.com> - 0.1.0
- Initial RPM release.

# Local variables:
# mode: shell-script
# sh-shell: rpm
# end:
